@@ -380,16 +380,16 @@ gegl_typeeditor_optype (GtkSizeGroup   *col1,
                         GtkSizeGroup   *col2,
                         GeglNodeEditor *node_editor)
 {
-  GtkWidget *hbox;
-  GtkWidget *label = NULL;
-  GtkWidget *hbox2;
-  GtkWidget *entry;
+  GtkWidget   *hbox;
+  GtkWidget   *label = NULL;
+  GtkWidget   *hbox2;
+  GtkWidget   *entry;
   GtkEntryCompletion *completion;
   GtkTreeModel *completion_model;
-  GtkWidget *button;
-  GtkWidget *button_arrow;
-  char     *current_type;
-  GeglNode  *item = NULL;
+  GtkWidget   *button;
+  GtkWidget   *button_arrow;
+  gchar       *current_type = NULL;
+  GeglNode    *item = NULL;
 
   if (node_editor)
     item =node_editor->node;
@@ -411,11 +411,11 @@ gegl_typeeditor_optype (GtkSizeGroup   *col1,
 
   if (item)
     {
-  current_type = g_strdup (gegl_node_get_operation (item));
+      current_type = g_strdup (gegl_node_get_operation (item));
     }
   else
     {
-      current_type = g_strdup ("Type a GEGL operation, or examine to dropdown menu to the right");
+      current_type = g_strdup ("Write the name of a GEGL operation to apply or examine use the dropdown menu in the upper right");
     }
 
   if (label) gtk_box_pack_start (GTK_BOX (hbox), label, FALSE, FALSE, 0);
