@@ -22,11 +22,8 @@
 #include <stdlib.h>
 #include <stdio.h>
 
-#include "gegl-bin-types.h"
-
 #include "gegl-options.h"
 
-
 static GeglOptions *opts_new (void)
 {
   GeglOptions *o = g_malloc0 (sizeof (GeglOptions));
@@ -226,6 +223,11 @@ parse_args (int    argc,
             o->verbose=1;
         }
 
+        else if (match ("--g-fatal-warnings") ||
+                 match ("-v")) {
+            o->fatal_warnings=1;
+        }
+
         else if (match ("-p")){
             o->play=TRUE;
         }
