@@ -25,6 +25,7 @@
 #include "gegl.h"
 
 #include "editor.h"
+#include "editor-optype.h"
 #include "gegl-node-editor.h"
 #include "gegl-plugin.h"
 #include "gegl-store.h"
@@ -35,15 +36,26 @@
 void property_editor_rebuild (GtkWidget *container,
                               GeglNode  *node)
 {
-  GtkWidget *editor;
+  GeglNodeEditor *node_editor;
+  GtkWidget      *node_editor_widget;
+  GtkWidget      *operation_switcher;
 
   gtk_container_foreach (GTK_CONTAINER (container),
                          (GtkCallback) gtk_widget_destroy, NULL);
 
-  /*editor = property_editor_general (col1, col2, node);*/
-  editor = gegl_node_editor_new (node, TRUE);
-  if (editor)
-    gtk_box_pack_start (GTK_BOX (container), editor, TRUE, TRUE, 0);
+  node_editor_widget = gegl_node_editor_new (node);
+  node_editor        = GEGL_NODE_EDITOR (node_editor_widget);
+  operation_switcher = gegl_typeeditor_optype (node_editor->col1, node_editor->col2, node_editor);
+
+  if (operation_switcher)
+    {
+      gtk_box_pack_start (GTK_BOX (container), operation_switcher, FALSE, FALSE, 0);
+    }
+  if (node_editor_widget)
+    {
+      gtk_box_pack_start (GTK_BOX (container), node_editor_widget, TRUE, TRUE, 0);
+    }
+
   gtk_widget_show_all (container);
 }
 
@@ -60,11 +72,11 @@ action_move_up (GtkAction *action,
                 gpointer   userdata);
                 */
 
-gboolean
- view_onButtonPressed (GtkWidget *treeview, GdkEventButton *event,
-                       gpointer userdata);
+static gboolean view_onButtonPressed (GtkWidget      *treeview,
+                                      GdkEventButton *event,
+                                      gpointer        userdata);
 
-void
+static void
 cell_edited_callback (GtkCellRendererText * cell,
                       gchar *path_string, gchar *new_text, gpointer user_data)
 {
@@ -90,6 +102,8 @@ cell_edited_callback (GtkCellRendererText * cell,
   gtk_tree_path_free (path);
 }
 
+void editor_set_active (gpointer, gpointer);
+
 static void
 selection_changed (GtkTreeSelection * selection, gpointer user_data)
 {
@@ -101,9 +115,7 @@ selection_changed (GtkTreeSelection * selection, gpointer user_data)
   top_vbox = user_data;
   if (!gtk_tree_selection_get_selected (selection, &model, &iter))
     {
-#ifdef HAVE_GRAPH_EDITOR
-      graph_editor_set_root (editor->graph_editor, NULL);
-#endif
+      editor_set_active (editor.view, NULL);
       return;
     }
 
@@ -112,16 +124,8 @@ selection_changed (GtkTreeSelection * selection, gpointer user_data)
   if (item)
     {
       property_editor_rebuild (top_vbox, item);
-
-#ifdef HAVE_CURVE_EDITOR
-      curve_editor_set_gegl (editor->curve_editor, item);
-#endif
-#ifdef HAVE_GRAPH_EDITOR
-      if (gegl_type (item) == GeglGraph)
-        graph_editor_set_root (editor->graph_editor, item);
-      else
-        graph_editor_set_root (editor->graph_editor, NULL);
-#endif
+      editor_set_active (editor.view, item);
+      /* a signal would have been the correct approach here */
     }
 }
 
@@ -234,8 +238,9 @@ tree_editor_new (GtkWidget *property_editor)
     }
   }
 
-  g_signal_connect (G_OBJECT (treeview), "button-press-event",
-                    (GCallback) view_onButtonPressed, NULL);
+  g_signal_connect (treeview, "button-press-event",
+                    G_CALLBACK (view_onButtonPressed),
+                    NULL);
 
   tree_scroll = gtk_scrolled_window_new (NULL, NULL);
   gtk_scrolled_window_set_policy (GTK_SCROLLED_WINDOW (tree_scroll),
@@ -307,7 +312,7 @@ static const gchar *ui_info =
   "  </popup>"
   "</ui>";
 
-void
+static void
 view_popup_menu (GtkWidget *treeview, GdkEventButton *event,
                  gpointer userdata)
 {
@@ -365,9 +370,10 @@ view_popup_menu (GtkWidget *treeview, GdkEventButton *event,
   return;
 }
 
-gboolean
-view_onButtonPressed (GtkWidget *treeview, GdkEventButton *event,
-                      gpointer userdata)
+static gboolean
+view_onButtonPressed (GtkWidget      *treeview,
+                      GdkEventButton *event,
+                      gpointer        userdata)
 {
   /* single click with the right mouse button? */
   if (event->type == GDK_BUTTON_PRESS && event->button == 3)
