@@ -19,9 +19,6 @@
 #ifndef GEGL_TREE_EDITOR_H
 #define GEGL_TREE_EDITOR_H
 
-#include "gegl-tree-editor-action.h"
-#include <gegl.h>
-#include "gegl-store.h"
 
 GtkWidget * tree_editor_new          (GtkWidget *property_editor);
 
@@ -35,4 +32,5 @@ GtkWidget * tree_editor_get_treeview (GtkWidget *tree_editor);
 void        property_editor_rebuild  (GtkWidget *container,
                                       GeglNode  *node);
 
-#endif /* TREE_EDITOR_H */
+
+#endif /* GEGL_TREE_EDITOR_H */
