@@ -32,7 +32,8 @@ enum
   PROP_NODE,
   PROP_X,
   PROP_Y,
-  PROP_SCALE
+  PROP_SCALE,
+  PROP_BLOCK
 };
 
 
@@ -42,6 +43,8 @@ typedef struct _GeglViewPrivate
   gint           x;
   gint           y;
   gdouble        scale;
+  gboolean       block;    /* blocking render */
+
   gint           screen_x;    /* coordinates of drag start */
   gint           screen_y;
 
@@ -59,6 +62,15 @@ typedef struct _GeglViewPrivate
   GeglProcessor *processor;
 } GeglViewPrivate;
 
+enum
+{
+  DETECTED,
+  LAST_SIGNAL
+};
+
+
+static gint gegl_view_signals[LAST_SIGNAL] = {0, };
+
 
 G_DEFINE_TYPE (GeglView, gegl_view, GTK_TYPE_DRAWING_AREA)
 #define GEGL_VIEW_GET_PRIVATE(obj) \
@@ -79,6 +91,8 @@ static gboolean  motion_notify_event  (GtkWidget      *widget,
                                        GdkEventMotion *event);
 static gboolean  button_press_event   (GtkWidget      *widget,
                                        GdkEventButton *event);
+static gboolean  button_release_event (GtkWidget      *widget,
+                                       GdkEventButton *event);
 static gboolean  expose_event         (GtkWidget      *widget,
                                        GdkEventExpose *event);
 
@@ -95,6 +109,7 @@ gegl_view_class_init (GeglViewClass * klass)
 
   widget_class->motion_notify_event = motion_notify_event;
   widget_class->button_press_event  = button_press_event;
+  widget_class->button_release_event = button_release_event;
   widget_class->expose_event        = expose_event;
 
   g_object_class_install_property (gobject_class, PROP_X,
@@ -125,6 +140,24 @@ gegl_view_class_init (GeglViewClass * klass)
                                                         G_TYPE_OBJECT,
                                                         G_PARAM_CONSTRUCT |
                                                         G_PARAM_READWRITE));
+  g_object_class_install_property (gobject_class, PROP_BLOCK,
+                                   g_param_spec_boolean ("block",
+                                                        "Blocking render",
+                                                        "Make sure all data requested to blit is generated.",
+                                                        FALSE,
+                                                        G_PARAM_READWRITE));
+
+ gegl_view_signals[DETECTED] =
+   g_signal_new ("detected",
+                  G_TYPE_FROM_CLASS (klass),
+                  G_SIGNAL_RUN_LAST | G_SIGNAL_NO_RECURSE | G_SIGNAL_NO_HOOKS,
+                  0,
+                  NULL, NULL,
+                  g_cclosure_marshal_VOID__OBJECT,
+                  G_TYPE_NONE, 1,
+                  GEGL_TYPE_NODE);
+
+
    g_type_class_add_private (klass, sizeof (GeglViewPrivate));
 }
 
@@ -143,6 +176,7 @@ gegl_view_init (GeglView *self)
 
   gtk_widget_add_events (GTK_WIDGET (self), (GDK_EXPOSURE_MASK     |
                                              GDK_BUTTON_PRESS_MASK |
+                                             GDK_BUTTON_RELEASE_MASK |
                                              GDK_POINTER_MOTION_MASK));
 }
 
@@ -228,6 +262,9 @@ set_property (GObject      *gobject,
       priv->x = g_value_get_int (value);
       gtk_widget_queue_draw (GTK_WIDGET (self));
       break;
+    case PROP_BLOCK:
+      priv->block = g_value_get_boolean (value);
+      break;
     case PROP_Y:
       priv->y = g_value_get_int (value);
       gtk_widget_queue_draw (GTK_WIDGET (self));
@@ -260,6 +297,9 @@ get_property (GObject      *gobject,
     case PROP_X:
       g_value_set_int (value, priv->x);
       break;
+    case PROP_BLOCK:
+      g_value_set_boolean (value, priv->block);
+      break;
     case PROP_Y:
       g_value_set_int (value, priv->y);
       break;
@@ -272,6 +312,15 @@ get_property (GObject      *gobject,
     }
 }
 
+static void
+detected_event (GeglView *self,
+                GeglNode *node)
+{
+  g_signal_emit (self, gegl_view_signals[DETECTED], 0, node, NULL, NULL);
+}
+
+static gboolean drag_started = FALSE;
+
 static gboolean
 button_press_event (GtkWidget      *widget,
                     GdkEventButton *event)
@@ -281,6 +330,8 @@ button_press_event (GtkWidget      *widget,
   gint      x    = event->x;
   gint      y    = event->y;
 
+  return FALSE;
+
   priv->screen_x = x;
   priv->screen_y = y;
 
@@ -302,24 +353,22 @@ button_press_event (GtkWidget      *widget,
                                            (priv->y + event->y) / priv->scale);
     if (detected)
       {
-#if 0
-        gchar *name;
-        gchar *operation;
-
-        gegl_node_get (detected, "name", &name, "operation", &operation, NULL);
-        g_warning ("%s:%s(%p)", operation, name, detected);
-        g_free (name);
-        g_free (operation);
-#endif
-#if 0
-        tree_editor_set_active (editor.tree_editor, detected);
-#endif
+        detected_event (view, detected);
       }
   }
 
+  drag_started = TRUE;
   return TRUE;
 }
 
+static gboolean
+button_release_event (GtkWidget      *widget,
+                      GdkEventButton *event)
+{
+  drag_started = FALSE;
+  return FALSE;
+}
+
 static gboolean
 motion_notify_event (GtkWidget      *widget,
                      GdkEventMotion *event)
@@ -329,6 +378,8 @@ motion_notify_event (GtkWidget      *widget,
   gint      x    = event->x;
   gint      y    = event->y;
 
+  if (drag_started)
+    {
   if (event->state & GDK_BUTTON1_MASK)
     {
       gint diff_x = x - priv->prev_x;
@@ -342,40 +393,42 @@ motion_notify_event (GtkWidget      *widget,
       g_object_notify (G_OBJECT (view), "x");
       g_object_notify (G_OBJECT (view), "y");
     }
-  else if (event->state & GDK_BUTTON3_MASK)
+  else if (event->state & GDK_BUTTON2_MASK)
     {
-      gint diff = priv->prev_y - y;
-      gint i;
+        gint diff = priv->prev_y - y;
+        gint i;
 
-      if (diff < 0)
-        {
-          for (i=0;i>diff;i--)
-            {
-              priv->scale /= 1.006;
-            }
-        }
-      else
-        {
-          for (i=0;i<diff;i++)
-            {
-              priv->scale *= 1.006;
-            }
-        }
+        if (diff < 0)
+          {
+            for (i=0;i>diff;i--)
+              {
+                priv->scale /= 1.006;
+              }
+          }
+        else
+          {
+            for (i=0;i<diff;i++)
+              {
+                priv->scale *= 1.006;
+              }
+          }
 
-      priv->x = (priv->start_buf_x - priv->screen_x / priv->scale) * priv->scale;
-      priv->y = (priv->start_buf_y - priv->screen_y / priv->scale) * priv->scale;
+        priv->x = (priv->start_buf_x - priv->screen_x / priv->scale) * priv->scale;
+        priv->y = (priv->start_buf_y - priv->screen_y / priv->scale) * priv->scale;
 
-      gtk_widget_queue_draw (GTK_WIDGET (view));
+        gtk_widget_queue_draw (GTK_WIDGET (view));
 
-      g_object_notify (G_OBJECT (view), "x");
-      g_object_notify (G_OBJECT (view), "y");
-      g_object_notify (G_OBJECT (view), "scale");
+        g_object_notify (G_OBJECT (view), "x");
+        g_object_notify (G_OBJECT (view), "y");
+        g_object_notify (G_OBJECT (view), "scale");
+      }
+
+      priv->prev_x = x;
+      priv->prev_y = y;
+
+      return TRUE;
     }
-
-  priv->prev_x = x;
-  priv->prev_y = y;
-
-  return TRUE;
+  return FALSE;
 }
 
 static gboolean
@@ -411,7 +464,7 @@ expose_event (GtkWidget      *widget,
                       babl_format ("R'G'B' u8"),
                       (gpointer)buf,
                       GEGL_AUTO_ROWSTRIDE,
-                      GEGL_BLIT_CACHE|GEGL_BLIT_DIRTY);
+                      GEGL_BLIT_CACHE|(priv->block?0:GEGL_BLIT_DIRTY));
 
       gdk_draw_rgb_image (widget->window,
                           widget->style->black_gc,
