@@ -98,10 +98,18 @@ GeglTileBackend    * gegl_buffer_backend     (GeglBuffer *buffer);
 gboolean             gegl_buffer_is_shared   (GeglBuffer *buffer);
 
 gboolean             gegl_buffer_try_lock    (GeglBuffer *buffer);
+#if 0
 gboolean             gegl_buffer_lock        (GeglBuffer *buffer);
 gboolean             gegl_buffer_unlock      (GeglBuffer *buffer);
+#else
+#define gegl_buffer_lock(o)  {}
+#define gegl_buffer_unlock(o)  {}
+#endif
 
 
+GeglBuffer *
+gegl_buffer_new_ram (const GeglRectangle *extent,
+                     const Babl          *format);
 
 GType gegl_sampler_type_from_interpolation (GeglInterpolation interpolation);
 
