@@ -13,7 +13,7 @@
  * You should have received a copy of the GNU Lesser General Public
  * License along with this library; if not, see <http://www.gnu.org/licenses/>.
  *
- * Copyright 2006,2007 Øyvind Kolås <pippin@gimp.org>
+ * Copyright 2006-2008 Øyvind Kolås <pippin@gimp.org>
  */
 
 #include "config.h"
@@ -108,7 +108,8 @@ static GeglBuffer * gegl_buffer_new_from_format (const void *babl_format,
                                                  gint        width,
                                                  gint        height,
                                                  gint        tile_width,
-                                                 gint        tile_height);
+                                                 gint        tile_height,
+                                                 gboolean    use_ram);
 
 static inline gint needed_tiles (gint w,
                                  gint stride)
@@ -285,14 +286,15 @@ set_property (GObject      *gobject,
 static gint allocated_buffers    = 0;
 static gint de_allocated_buffers = 0;
 
-  /* this should only be possible if this buffer matches all the buffers down to
-   * storage, all of those parent buffers would change size as well, no tiles
-   * would be voided as a result of changing the extent.
-   */
+/* this should only be possible if this buffer matches all the buffers down to
+ * storage, all of those parent buffers would change size as well, no tiles
+ * would be voided as a result of changing the extent.
+ */
 gboolean
 gegl_buffer_set_extent (GeglBuffer          *buffer,
                         const GeglRectangle *extent)
 {
+  g_return_val_if_fail(GEGL_IS_BUFFER(buffer), FALSE);
    (*(GeglRectangle*)gegl_buffer_get_extent (buffer))=*extent;
 
   if ((GeglBufferHeader*)(gegl_buffer_backend (buffer)->header))
@@ -445,7 +447,28 @@ gegl_buffer_constructor (GType                  type,
        * source (this adds a redirection buffer in between for
        * all "allocated from format", type buffers.
        */
-      if (buffer->path)
+      if (buffer->path && g_str_equal (buffer->path, "RAM"))
+        {
+          source = GEGL_TILE_SOURCE (gegl_buffer_new_from_format (buffer->format,
+                                                             buffer->extent.x,
+                                                             buffer->extent.y,
+                                                             buffer->extent.width,
+                                                             buffer->extent.height,
+                                                             buffer->tile_width,
+                                                             buffer->tile_height, TRUE));
+          /* after construction,. x and y should be set to reflect
+           * the top level behavior exhibited by this buffer object.
+           */
+          g_object_set (buffer,
+                        "source", source,
+                        NULL);
+          g_object_unref (source);
+
+          g_assert (source);
+          backend = gegl_buffer_backend (GEGL_BUFFER (source));
+          g_assert (backend);
+        }
+      else if (buffer->path)
         {
           GeglBufferHeader *header;
           GeglTileSource   *storage;
@@ -490,14 +513,13 @@ gegl_buffer_constructor (GType                  type,
         }
       else if (buffer->format)
         {
-
           source = GEGL_TILE_SOURCE (gegl_buffer_new_from_format (buffer->format,
                                                              buffer->extent.x,
                                                              buffer->extent.y,
                                                              buffer->extent.width,
                                                              buffer->extent.height,
                                                              buffer->tile_width,
-                                                             buffer->tile_height));
+                                                             buffer->tile_height, FALSE));
           /* after construction,. x and y should be set to reflect
            * the top level behavior exhibited by this buffer object.
            */
@@ -648,11 +670,6 @@ get_tile (GeglTileSource *source,
     {
       GeglBuffer *buffer = GEGL_BUFFER (handler);
 
-      /* not sure if this plays well with shifting */
-      tile->x = x;
-      tile->y = y;
-      tile->z = z;
-
       if (x < buffer->min_x)
         buffer->min_x = x;
       if (y < buffer->min_y)
@@ -681,12 +698,12 @@ get_tile (GeglTileSource *source,
 
 
 static gpointer
-command (GeglTileSource     *source,
-         GeglTileCommand command,
-         gint            x,
-         gint            y,
-         gint            z,
-         gpointer        data)
+gegl_buffer_command (GeglTileSource *source,
+                     GeglTileCommand command,
+                     gint            x,
+                     gint            y,
+                     gint            z,
+                     gpointer        data)
 {
   GeglTileHandler *handler = GEGL_HANDLER (source);
   switch (command)
@@ -710,7 +727,7 @@ gegl_buffer_class_init (GeglBufferClass *class)
   gobject_class->constructor  = gegl_buffer_constructor;
   gobject_class->set_property = set_property;
   gobject_class->get_property = get_property;
-  tile_source_class->command = command;
+  tile_source_class->command = gegl_buffer_command;
 
   g_object_class_install_property (gobject_class, PROP_PX_SIZE,
                                    g_param_spec_int ("px-size", "pixel-size", "size of a single pixel in bytes.",
@@ -844,6 +861,29 @@ gegl_buffer_get_extent (GeglBuffer *buffer)
   return &(buffer->extent);
 }
 
+
+GeglBuffer *
+gegl_buffer_new_ram (const GeglRectangle *extent,
+                     const Babl          *format)
+{
+  GeglRectangle empty={0,0,0,0};
+
+  if (extent==NULL)
+    extent = &empty;
+
+  if (format==NULL)
+    format = babl_format ("RGBA float");
+
+  return g_object_new (GEGL_TYPE_BUFFER,
+                       "x", extent->x,
+                       "y", extent->y,
+                       "width", extent->width,
+                       "height", extent->height,
+                       "format", format,
+                       "path", "RAM",
+                       NULL);
+}
+
 GeglBuffer *
 gegl_buffer_new (const GeglRectangle *extent,
                  const Babl          *format)
@@ -865,15 +905,39 @@ gegl_buffer_new (const GeglRectangle *extent,
                        NULL);
 }
 
+
+/* FIXME: this function needs optimizing, perhaps keep a pool
+ * of GeglBuffer shells that can be adapted to the needs
+ * on runtime, and recycling them through a hashtable?
+ */
 GeglBuffer*
 gegl_buffer_create_sub_buffer (GeglBuffer          *buffer,
                                const GeglRectangle *extent)
 {
   g_return_val_if_fail (GEGL_IS_BUFFER (buffer), NULL);
 
-  if (extent == NULL)
-    extent = gegl_buffer_get_extent (buffer);
+#if 1
+  if (extent == NULL || gegl_rectangle_equal (extent, &buffer->extent))
+    {
+      g_object_ref (buffer);
+      return buffer;
+    }
+#else
+   if (extent == NULL)
+      extent = gegl_buffer_get_extent (buffer);
+#endif
 
+  if (extent->width < 0 || extent->height < 0)
+    {
+      g_warning ("avoiding creating buffer of size: %ix%i returning an empty buffer instead.\n", extent->width, extent->height);
+      return g_object_new (GEGL_TYPE_BUFFER,
+                           "source", buffer,
+                           "x", extent->x,
+                           "y", extent->y,
+                           "width", 0,
+                           "height", 0,
+                           NULL);
+    }
   return g_object_new (GEGL_TYPE_BUFFER,
                        "source", buffer,
                        "x", extent->x,
@@ -904,12 +968,14 @@ gegl_buffer_new_from_format (const void *babl_format,
                              gint        width,
                              gint        height,
                              gint        tile_width,
-                             gint        tile_height)
+                             gint        tile_height,
+                             gboolean    use_ram)
 {
   GeglTileStorage *tile_storage;
   GeglBuffer  *buffer;
 
-  if (!gegl_config()->swap ||
+  if (use_ram || 
+      !gegl_config()->swap ||
       g_str_equal (gegl_config()->swap, "RAM") ||
       g_str_equal (gegl_config()->swap, "ram"))
     {
@@ -1055,6 +1121,7 @@ gboolean gegl_buffer_try_lock (GeglBuffer *buffer)
   return TRUE;
 }
 
+#if 0
 gboolean gegl_buffer_lock (GeglBuffer *buffer)
 {
   while (gegl_buffer_try_lock (buffer)==FALSE)
@@ -1075,3 +1142,4 @@ gboolean gegl_buffer_unlock (GeglBuffer *buffer)
     return gegl_tile_backend_file_unlock (GEGL_TILE_BACKEND_FILE (backend));
   return TRUE;
 }
+#endif
