@@ -32,6 +32,7 @@
 #include "gegl-buffer-private.h"
 #include "gegl-tile.h"
 #include "gegl-tile-source.h"
+#include "gegl-tile-storage.h"
 
 
 G_DEFINE_TYPE (GeglTile, gegl_tile, G_TYPE_OBJECT)
@@ -283,7 +284,7 @@ _gegl_tile_void_pyramid (GeglTileSource *source,
                          gint            y,
                          gint            z)
 {
-  if (z>10)
+  if (z > ((GeglTileStorage*)source)->seen_zoom)
     return;
   gegl_tile_source_void (source, x, y, z);
   _gegl_tile_void_pyramid (source, x/2, y/2, z+1);
@@ -293,6 +294,7 @@ static void
 gegl_tile_void_pyramid (GeglTile *tile)
 {
   if (tile->tile_storage && 
+      tile->tile_storage->seen_zoom &&
       tile->z == 0) /* we only accepting voiding the base level */
     {
       _gegl_tile_void_pyramid (GEGL_TILE_SOURCE (tile->tile_storage), 
@@ -378,12 +380,6 @@ gegl_tile_swp (GeglTile *a,
   b->data = tmp;
 }
 
-unsigned char *
-gegl_tile_get_data (GeglTile *tile)
-{
-  return tile->data;
-}
-
 gboolean gegl_tile_store (GeglTile *tile)
 {
   if (gegl_tile_is_stored (tile))
@@ -397,32 +393,6 @@ gboolean gegl_tile_store (GeglTile *tile)
                                     tile);
 }
 
-/* compute the tile indice of a coordinate
- * the stride is the width/height of tiles along the axis of coordinate
- */
-gint
-gegl_tile_indice (gint coordinate,
-                  gint stride)
-{
-  if (coordinate >= 0)
-    return coordinate / stride;
-  return (((coordinate + 1) / stride) - 1);
-}
-
-/* computes the positive integer remainder (also for negative dividends)
- */
-#define REMAINDER(dividend, divisor) \
-                   (((dividend) < 0) ? \
-                    (divisor) - 1 - ((-((dividend) + 1)) % (divisor)) : \
-                    (dividend) % (divisor))
 
 
-/* compute the offset into the containing tile a coordinate has,
- * the stride is the width/height of tiles along the axis of coordinate
- */
-gint
-gegl_tile_offset (gint coordinate,
-                  gint stride)
-{
-  return REMAINDER (coordinate, stride);
-}
+
