@@ -26,17 +26,6 @@
 #include "gegl-types.h"
 
 
-static void gegl_logv        (GLogLevelFlags  level,
-                              const gchar    *file,
-                              gint            line,
-                              const gchar    *function,
-                              const gchar    *format,
-                              va_list         args);
-static void gegl_direct_logv (GLogLevelFlags  level,
-                              const gchar    *format,
-                              va_list         args);
-
-
 inline gint
 _gegl_float_epsilon_zero (float value)
 {
@@ -176,99 +165,6 @@ gegl_rectangle_equal_coords (const GeglRectangle *r,
     return FALSE;
 }
 
-#define GEGL_LOG_DOMAIN    "Gegl"
-
-void
-gegl_log_debug (const gchar *file,
-                gint         line,
-                const gchar *function,
-                const gchar *format,
-                ...)
-{
-  va_list args;
-
-  va_start (args, format);
-  gegl_logv (G_LOG_LEVEL_DEBUG, file, line, function, format, args);
-  va_end (args);
-}
-
-void
-gegl_log_info (const gchar *file,
-               gint         line,
-               const gchar *function,
-               const gchar *format,
-               ...)
-{
-  va_list args;
-
-  va_start (args, format);
-  gegl_logv (G_LOG_LEVEL_INFO, file, line, function, format, args);
-  va_end (args);
-}
-
-void
-gegl_log_message (const gchar *file,
-                  gint         line,
-                  const gchar *function,
-                  const gchar *format,
-                  ...)
-{
-  va_list args;
-
-  va_start (args, format);
-  gegl_logv (G_LOG_LEVEL_MESSAGE, file, line, function, format, args);
-  va_end (args);
-}
-
-void
-gegl_log_direct (const gchar *format,
-                 ...)
-{
-  va_list args;
-
-  va_start (args, format);
-  gegl_direct_logv (G_LOG_LEVEL_DEBUG, format, args);
-  va_end (args);
-}
-
-static void
-gegl_logv (GLogLevelFlags  level,
-           const gchar    *file,
-           gint            line,
-           const gchar    *function,
-           const gchar    *format,
-           va_list         args)
-{
-  if (g_getenv ("GEGL_LOG_ON"))
-    {
-      gchar *tabbed = NULL;
-
-      /* log the file and line */
-      g_log (GEGL_LOG_DOMAIN, level, "%s:  %s:%d:", function, file, line);
-
-      /* move the regular output over a bit. */
-      tabbed = g_strconcat ("   ", format, NULL);
-      g_logv (GEGL_LOG_DOMAIN, level, tabbed, args);
-      g_log (GEGL_LOG_DOMAIN, level, "        ");
-      g_free (tabbed);
-    }
-}
-
-static void
-gegl_direct_logv (GLogLevelFlags  level,
-                  const gchar    *format,
-                  va_list         args)
-{
-  if (g_getenv ("GEGL_LOG_ON"))
-    {
-      gchar *tabbed = NULL;
-      tabbed = g_strconcat ("   ", format, NULL);
-      g_logv (GEGL_LOG_DOMAIN, level, tabbed, args);
-      g_free (tabbed);
-    }
-}
-
-
 static GeglRectangle *
 gegl_rectangle_dup (const GeglRectangle *rectangle)
 {
@@ -291,4 +187,35 @@ gegl_rectangle_get_type (void)
   return our_type;
 }
 
+#define GEGL_ALIGN 16
+
+gpointer
+gegl_malloc (gsize size);
+
+/* utility call that makes sure allocations are 16 byte aligned.
+ * making RGBA float buffers have aligned access for pixels.
+ */ 
+gpointer gegl_malloc (gsize size)
+{
+  gchar *mem;
+  gchar *ret;
+  gint   offset;
+
+  mem    = g_malloc (size + GEGL_ALIGN + sizeof(gpointer));
+  offset = GEGL_ALIGN - (((guint)mem) + sizeof(gpointer)) % GEGL_ALIGN;
+  ret    = (gpointer)(mem + sizeof(gpointer) + offset);
+
+  /* store the real malloc one pointer in front of this malloc */
+  *(gpointer*)(ret-sizeof(gpointer))=mem;
+  return (gpointer) ret;
+}
+
+void
+gegl_free (gpointer buf);
+void
+gegl_free (gpointer buf)
+{
+  g_assert (buf);
+  g_free (*((gpointer*)buf -1));
+}
 
