@@ -31,7 +31,7 @@
 #include "operation/gegl-operation.h"
 #include "property-types/gegl-color.h"
 #include "property-types/gegl-curve.h"
-#include "property-types/gegl-vector.h"
+#include "property-types/gegl-path.h"
 #include "property-types/gegl-paramspecs.h"
 #include "gegl-instrument.h"
 #include "gegl-xml.h"
@@ -119,7 +119,7 @@ set_clone_prop_as_well:
                      param_name, gegl_node_get_debug_name (new));
         }
       else if (g_type_is_a (G_PARAM_SPEC_TYPE (paramspec),
-                            GEGL_TYPE_PARAM_PATH))
+                            GEGL_TYPE_PARAM_FILE_PATH))
         {
           gchar buf[PATH_MAX];
 
@@ -195,11 +195,11 @@ set_clone_prop_as_well:
 	      pd->curve = NULL;
 	    }
 	}
-      else if (paramspec->value_type == GEGL_TYPE_VECTOR)
+      else if (paramspec->value_type == GEGL_TYPE_PATH)
         {
-          GeglVector *vector = gegl_vector_new ();
-          gegl_vector_parse_svg_path (vector, param_value);
-	  gegl_node_set (new, param_name, vector, NULL);
+          GeglPath *path = gegl_path_new ();
+          gegl_path_parse_string (path, param_value);
+	  gegl_node_set (new, param_name, path, NULL);
 	}
       else
         {
@@ -291,7 +291,19 @@ static void start_element (GMarkupParseContext *context,
     {
       GeglNode *new;
 
-      if (!strcmp (element_name, "node"))
+      if (!strcmp (element_name, "clone"))
+        {
+          new = gegl_node_new_child (pd->gegl,
+                                     "operation", "gegl:clone",
+                                     NULL);
+        }
+      else if (!strcmp (element_name, "layer"))
+        {
+          new = gegl_node_new_child (pd->gegl,
+                                     "operation", "gegl:layer",
+                                     NULL);
+        }
+      else if (!strcmp (element_name, "node"))
         {
           new = gegl_node_new_child (pd->gegl,
                                      "operation", name2val (a, v, "operation"),
@@ -988,7 +1000,7 @@ serialize_properties (SerializeState *ss,
             }
 
           if (g_type_is_a (G_PARAM_SPEC_TYPE (properties[i]),
-                           GEGL_TYPE_PARAM_PATH))
+                           GEGL_TYPE_PARAM_FILE_PATH))
             {
               gchar *value;
               gegl_node_get (node, properties[i]->name, &value, NULL);
@@ -1074,9 +1086,17 @@ serialize_properties (SerializeState *ss,
 	      indent += 2; ind; indent -= 2; xml_param_end (ss);
 	      g_object_unref (curve);
 	    }
-	  else if (properties[i]->value_type == GEGL_TYPE_VECTOR)
+	  else if (properties[i]->value_type == GEGL_TYPE_PATH)
 	    {
-              g_print ("serialization of GeglVector NYI\n");
+          gchar *svg_path;
+          GeglPath *path;
+	      gegl_node_get (node, properties[i]->name, &path, NULL);
+	      xml_param_start (ss, indent + 2, properties[i]->name);
+          svg_path = gegl_path_to_string (path);	      
+	      g_string_append (ss->buf, svg_path);
+	      xml_param_end (ss);
+
+          g_object_unref (path);
 	    }
           else
             {
@@ -1240,8 +1260,8 @@ add_stack (SerializeState *ss,
                 {
                   if (class)
                     {
-                      if (strcmp (class, "nop") &&
-                          strcmp (class, "clone"))
+                      if (strcmp (class, "gegl:nop") &&
+                          strcmp (class, "gegl:clone"))
                         {
                           ind; g_string_append (ss->buf, "<node");
 
