@@ -253,7 +253,7 @@ static void class_init (GeglOperationClass *operation_class);
 #endif
 
 static void create_matrix (GeglChantOperation *operation,
-                           Matrix3         matrix);
+                           GeglMatrix3         matrix);
 
 static void
 gegl_chant_class_init (ChantClass * klass)
@@ -277,7 +277,7 @@ gegl_chant_class_init (ChantClass * klass)
 #endif
 
 #define M_GEGL_CHANT_SET_NAME_EXTENDED(nam) \
-  operation_class->name=g_strdup(#nam);
+  operation_class->name=g_strdup("gegl:"#nam);
 #define M_GEGL_CHANT_SET_NAME(name)   M_GEGL_CHANT_SET_NAME_EXTENDED(name)
   M_GEGL_CHANT_SET_NAME (GEGL_CHANT_NAME);
 
