@@ -50,8 +50,7 @@ prepare (GeglOperation *operation)
 static GeglRectangle
 get_bounding_box (GeglOperation *operation)
 {
-  /*GeglRectangle result = {-10000000, -10000000, 20000000, 20000000};*/
-  GeglRectangle result = {40,40,540,540};
+  GeglRectangle result = {-10000000, -10000000, 20000000, 20000000};
   return result;
 }
 
@@ -130,7 +129,7 @@ gegl_chant_class_init (GeglChantClass *klass)
   operation_class->get_bounding_box = get_bounding_box;
   operation_class->prepare = prepare;
 
-  operation_class->name        = "checkerboard";
+  operation_class->name        = "gegl:checkerboard";
   operation_class->categories  = "render";
   operation_class->description = _("Checkerboard renderer");
 }
