@@ -85,7 +85,7 @@ gegl_chant_class_init (GeglChantClass *klass)
   operation_class->get_bounding_box = get_bounding_box;
   operation_class->prepare = prepare;
 
-  operation_class->name        = "color";
+  operation_class->name        = "gegl:color";
   operation_class->categories  = "render";
   operation_class->description =
         _("Generates a buffer entirely filled with the specified color, "
