@@ -56,6 +56,8 @@ process (GeglOperation       *op,
          glong                samples,
          const GeglRectangle *roi)
 {
+	int bpp = gegl_operation_get_format(op, "output")->format.bytes_per_pixel;
+	memcpy(out_buf, in_buf, samples * bpp);
   return TRUE;
 }
 
@@ -72,7 +74,7 @@ gegl_chant_class_init (GeglChantClass *klass)
   point_filter_class->process = process;
   operation_class->prepare = prepare;
 
-  operation_class->name       = "convert-format";
+  operation_class->name       = "gegl:convert-format";
   operation_class->categories = "core:color";
   operation_class->description =
         _("Convert the data to the specified format");
