@@ -150,7 +150,7 @@ gegl_chant_class_init (GeglChantClass *klass)
   operation_class->get_bounding_box = get_bounding_box;
   operation_class->get_required_for_output = get_required_for_output;
 
-  operation_class->name        = "crop";
+  operation_class->name        = "gegl:crop";
   operation_class->categories  = "core";
   operation_class->description = _("Crop a buffer");
 
