@@ -22,7 +22,7 @@
 
 #ifdef GEGL_CHANT_PROPERTIES
 
-gegl_chant_path (path, _("File"), "/home/pippin/input.avi", _("Path of file to load."))
+gegl_chant_file_path (path, _("File"), "/home/pippin/input.avi", _("Path of file to load."))
 gegl_chant_int (frame, _("Frame"), 0, 1000000, 0, _("frame number"))
 
 #else
@@ -32,7 +32,12 @@ gegl_chant_int (frame, _("Frame"), 0, 1000000, 0, _("frame number"))
 
 #include "gegl-chant.h"
 #include <errno.h>
-#include <ffmpeg/avformat.h>
+
+#ifdef HAVE_LIBAVFORMAT_AVFORMAT_H
+#include <libavformat/avformat.h>
+#else
+#include <avformat.h>
+#endif
 
 typedef struct
 {
@@ -283,7 +288,7 @@ prepare (GeglOperation *operation)
       p->enc = p->video_st->codec;
       p->codec = avcodec_find_decoder (p->enc->codec_id);
 
-      p->enc->error_resilience = 2;
+      /* p->enc->error_resilience = 2; */
       p->enc->error_concealment = 3;
       p->enc->workaround_bugs = FF_BUG_AUTODETECT;
 
@@ -424,6 +429,12 @@ finalize (GObject *object)
   G_OBJECT_CLASS (gegl_chant_parent_class)->finalize (object);
 }
 
+static GeglRectangle
+get_cached_region (GeglOperation       *operation,
+                   const GeglRectangle *roi)
+{
+  return get_bounding_box (operation);
+}
 
 static void
 gegl_chant_class_init (GeglChantClass *klass)
@@ -438,9 +449,10 @@ gegl_chant_class_init (GeglChantClass *klass)
 
   source_class->process = process;
   operation_class->get_bounding_box = get_bounding_box;
+  operation_class->get_cached_region = get_cached_region;
   operation_class->prepare = prepare;
 
-  operation_class->name        = "ff-load";
+  operation_class->name        = "gegl:ff-load";
   operation_class->categories  = "input:video";
   operation_class->description = _("FFmpeg video frame importer.");
 }
