@@ -22,7 +22,7 @@
 
 #ifdef GEGL_CHANT_PROPERTIES
 
-gegl_chant_path (path, _("File"), "", _("Path of file to load."))
+gegl_chant_file_path (path, _("File"), "", _("Path of file to load."))
 
 #else
 
@@ -185,6 +185,12 @@ process (GeglOperation       *operation,
   return  TRUE;
 }
 
+static GeglRectangle
+get_cached_region (GeglOperation       *operation,
+                   const GeglRectangle *roi)
+{
+  return get_bounding_box (operation);
+}
 
 static void
 gegl_chant_class_init (GeglChantClass *klass)
@@ -197,18 +203,19 @@ gegl_chant_class_init (GeglChantClass *klass)
 
   source_class->process = process;
   operation_class->get_bounding_box = get_bounding_box;
+  operation_class->get_cached_region = get_cached_region;
 
-  operation_class->name        = "jpg-load";
+  operation_class->name        = "gegl:jpg-load";
   operation_class->categories  = "hidden";
   operation_class->description = _("JPG image loader");
 
 //  static gboolean done=FALSE;
 //  if (done)
 //    return;
-  gegl_extension_handler_register (".jpg", "jpg-load");
-  gegl_extension_handler_register (".JPG", "jpg-load");
-  gegl_extension_handler_register (".jpeg", "jpg-load");
-  gegl_extension_handler_register (".JPEG", "jpg-load");
+  gegl_extension_handler_register (".jpg", "gegl:jpg-load");
+  gegl_extension_handler_register (".JPG", "gegl:jpg-load");
+  gegl_extension_handler_register (".jpeg", "gegl:jpg-load");
+  gegl_extension_handler_register (".JPEG", "gegl:jpg-load");
 //  done = TRUE;
 }
 #endif
