@@ -23,11 +23,13 @@
 
 #ifdef GEGL_CHANT_PROPERTIES
 
-gegl_chant_path (path,   _("Path"), "/dev/video0", _("Path to v4l device"))
+gegl_chant_file_path (path,   _("Path"), "/dev/video0", _("Path to v4l device"))
 gegl_chant_int  (width,  _("Width"),  0, G_MAXINT, 320, _("Width for rendered image"))
 gegl_chant_int  (height, _("Height"), 0, G_MAXINT, 240, _("Height for rendered image"))
 gegl_chant_int  (frame,  _("Frame"),  0, G_MAXINT, 0, 
         _("current frame number, can be changed to trigger a reload of the image."))
+gegl_chant_int  (fps,    _("FPS"),  0, G_MAXINT, 0, 
+        _("autotrigger reload this many times a second."))
 
 #else
 
@@ -191,6 +193,13 @@ finalize (GObject *object)
   G_OBJECT_CLASS (gegl_chant_parent_class)->finalize (object);
 }
 
+static gboolean update (gpointer operation)
+{
+  GeglRectangle bounds = gegl_operation_get_bounding_box (operation);
+  gegl_operation_invalidate (operation, &bounds, FALSE);
+  return TRUE;
+}
+
 static gboolean
 process (GeglOperation       *operation,
          GeglBuffer          *output,
@@ -199,6 +208,13 @@ process (GeglOperation       *operation,
   GeglChantO *o = GEGL_CHANT_PROPERTIES (operation);
   Priv       *p = (Priv*)o->chant_data;
   guchar     *capbuf;
+  static gboolean inited = FALSE;
+
+    if (!inited && o->fps != 0)
+      {
+        inited= TRUE;
+        g_timeout_add (1000/o->fps, update, operation);
+      }
 
   if (!p->active)
     return FALSE;
@@ -276,6 +292,13 @@ process (GeglOperation       *operation,
   return  TRUE;
 }
 
+static GeglRectangle
+get_cached_region (GeglOperation       *operation,
+                   const GeglRectangle *roi)
+{
+  return get_bounding_box (operation);
+}
+
 static void
 gegl_chant_class_init (GeglChantClass *klass)
 {
@@ -289,9 +312,10 @@ gegl_chant_class_init (GeglChantClass *klass)
 
   source_class->process             = process;
   operation_class->get_bounding_box = get_bounding_box;
+  operation_class->get_cached_region = get_cached_region;
   operation_class->prepare          = prepare;
 
-  operation_class->name        = "v4l";
+  operation_class->name        = "gegl:v4l";
   operation_class->categories  = "input:video";
   operation_class->description = 
     _("Video4Linux input, webcams framegrabbers and similar devices.");
