@@ -454,18 +454,18 @@ stuff (gint    argc,
       GeglNode  *gegl = g_object_new (GEGL_TYPE_NODE, NULL);
 
       GeglNode  *save = gegl_node_new_child (gegl,
-                    "operation", "png-save",
+                    "operation", "gegl:png-save",
                     "path", "/dev/null",
                     NULL);
       GeglNode *crop = gegl_node_new_child (gegl,
-       "operation", "crop",
+       "operation", "gegl:crop",
        "x", 0,
        "y", 0,
        "width", 50,
        "height", 50,
        NULL);
       GeglNode  *png_load = gegl_node_new_child (gegl,
-                    "operation", "checkerboard",
+                    "operation", "gegl:checkerboard",
                     NULL);
 
       /* connect operations */
